# IBS_for_Xsuite

This is my fork of M. Zampetakis' work on an Intra-Beam Scattering (IBS) implementation (originally at https://github.com/MichZampetakis/IBS_for_Xsuite).
It is meant as a starting point to improve and eventually include into `xsuite`, one of the main goals of my fellowship.
As inherited from Michalis, `Xsuite_IBS.py `is the main script to run which performs tracking with the IBS implementation on the CLIC Damping Ring.
In `lib/IBSfunctions.py` are the implementations for both of the kicks + Nagaitsev analytical calculation.
